# حساب
یک نرم‌افزار خط‌فرمان حسابداری شخصی با تقویم شمسی

## نصب و استفاده
محیط مجازی پابتونی‌ای در مسیر بسته ایجاد کرده و پس از فعّال کردنش بسته را در آن نصب می‌کنیم:
```bash
$ cd hesab
$ python3 -m venv venv
$ source venv/bin/activate
$ pip install .
```

## استفاده
اگر در محیط مجازی نیستیم واردش می‌شویم:
```bash
$ cd hesab
$ source venv/bin/activate
```
حال با دستور `hesab` به برنامه دسترسی خواهیم داشت.
### اجرا با چند مثال:
```bash
./hesab --help
./hesab add "ice cream" -20
./hesab list
```

## نقشهٔ راه توسعه
در هر نگارش اصلی قرار است یک سری ویژگی به نرم‌افزار افزوده شوند.

### نگارش ۰٫۲
ویژگی‌هایی که انتظار می‌رود در **دومین** انتشار این نرم‌افزار موجود باشند:
- امکان ذخیرهٔ یکای جایگزین (قیمت روز تخم‌مرغ) در هر تراکنش.
- خروجی قشنگ‌تر.
- افزودن یک فایل کانفیگ

### نگارش ۱
ویژگی‌هایی که انتظار می‌رود در نگارش ۱ نرم‌افزار موجود باشند:
- یک رابط خط‌فرمان قابل‌استفاده، ساده و زیبا
- امکان ذخیره کردن عنوان هزینه‌ها و در‌آمدها، مقدار پول و تاریخ آن‌ها به همراه اطلاعات اضافی شامل توضیحات و قیمت بر حسب یکای جایگزین
- یک بسته‌بندی مناسب و قابل‌نصب برای نرم‌افزار
